select count(*) from test where q3c_ellipse_query(ra,dec,171.890000,-85.710000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,45.360000,-8.020000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,247.030000,50.850000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,308.900000,42.260000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,122.970000,58.380000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,301.240000,-38.620000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,15.710000,-15.310000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,238.380000,-33.890000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,141.250000,-86.890000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,336.320000,-80.060000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,355.590000,-23.100000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,91.060000,31.500000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,154.730000,-58.350000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,78.600000,40.910000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,114.670000,-24.360000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,154.940000,-45.770000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,91.410000,88.290000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,176.080000,-14.160000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,300.950000,36.530000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,358.020000,68.830000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,239.290000,59.230000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,196.760000,13.430000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,122.430000,-80.440000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,268.300000,-46.640000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,166.370000,35.410000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,68.640000,0.290000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,227.110000,17.800000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,173.780000,6.180000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,160.650000,17.270000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,79.720000,-26.260000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,182.990000,18.270000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,2.460000,34.780000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,150.130000,-38.420000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,158.000000,-3.370000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,278.070000,-25.310000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,42.340000,76.560000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,62.810000,-9.770000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,231.480000,-55.870000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,80.350000,12.320000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,221.420000,31.650000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,186.690000,-48.980000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,228.160000,72.530000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,237.830000,-75.290000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,107.700000,87.710000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,89.770000,-49.510000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,76.040000,40.040000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,318.510000,-77.440000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,349.180000,-43.310000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,60.050000,58.680000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,63.120000,-20.420000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,250.390000,14.480000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,153.860000,-16.300000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,25.530000,85.960000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,117.400000,23.600000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,321.470000,-0.210000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,169.740000,-12.270000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,274.210000,-28.190000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,166.880000,80.870000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,99.750000,73.350000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,324.820000,-25.490000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,14.090000,65.660000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,139.560000,45.280000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,233.230000,62.310000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,187.100000,21.300000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,253.170000,39.610000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,323.440000,76.630000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,289.910000,-5.030000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44.580000,53.660000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,199.450000,33.330000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,286.520000,53.460000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,197.790000,21.540000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,185.260000,54.270000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,140.930000,70.780000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316.800000,-2.190000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,244.870000,46.940000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,177.140000,-16.250000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,5.610000,89.050000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,342.280000,32.050000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,359.150000,-24.380000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,308.220000,-46.580000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,81.490000,39.140000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,290.960000,47.670000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,108.630000,28.360000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,146.500000,-69.860000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,296.570000,58.780000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,90.840000,-13.920000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,141.310000,51.030000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,339.980000,53.060000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,218.850000,-2.770000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,29.920000,11.400000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,25.190000,-24.550000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,96.660000,-57.510000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136.330000,-87.950000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,36.200000,35.280000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,48.270000,-7.860000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,64.540000,60.620000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,337.010000,-82.080000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,37.680000,33.690000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,138.550000,75.150000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,171.620000,84.380000,0.1,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,28.890000,-72.530000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,322.360000,75.710000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224.030000,-61.150000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,345.900000,50.220000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,219.970000,4.000000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,98.240000,64.370000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,232.710000,-33.270000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,155.380000,-49.080000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,118.250000,66.380000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,92.590000,52.200000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,248.060000,-55.650000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,11.730000,25.770000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,355.600000,-48.020000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,91.670000,-48.620000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,191.940000,-85.670000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,188.410000,-5.550000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,333.080000,21.760000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,157.950000,67.920000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,275.020000,3.380000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,216.290000,26.640000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,233.760000,5.400000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,219.430000,-30.210000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,65.300000,-42.440000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,23.370000,-68.730000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,345.640000,-52.500000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,204.110000,38.080000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,210.780000,-16.780000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,257.650000,56.770000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,236.720000,43.400000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,39.990000,-52.200000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,279.460000,55.860000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,127.130000,-12.070000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,195.000000,-16.060000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,15.070000,-79.330000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,199.340000,20.890000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,279.810000,14.620000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,148.480000,-7.710000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,57.350000,69.940000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,258.420000,-53.570000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,283.690000,-27.340000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,25.160000,-47.260000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,94.830000,-2.820000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,24.700000,8.140000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,66.770000,-43.420000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,113.040000,51.490000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,55.510000,81.080000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,146.180000,85.970000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,277.050000,24.410000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,340.120000,49.470000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,227.390000,-41.760000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,190.860000,-26.980000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,122.530000,-25.460000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,274.400000,67.140000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,178.470000,-44.000000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,86.740000,16.300000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,251.210000,-85.560000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,203.880000,1.260000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,196.750000,77.200000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,121.820000,29.530000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,231.090000,1.530000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,56.560000,-86.280000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,210.230000,-42.990000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224.100000,77.960000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,350.170000,75.930000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,120.440000,-47.680000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,146.910000,-28.280000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,321.580000,75.160000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,176.450000,85.300000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,323.520000,-16.410000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,294.790000,79.530000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,342.260000,-8.180000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,357.930000,41.590000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,233.800000,17.590000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,221.870000,-6.620000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,214.140000,-43.450000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,102.610000,49.910000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,139.280000,-15.320000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,216.150000,-34.290000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,225.220000,68.670000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,58.490000,49.250000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,327.960000,-55.660000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,205.630000,25.290000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,303.500000,-76.970000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,153.570000,-14.660000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,7.840000,6.000000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,118.310000,6.010000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,16.980000,6.810000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,315.850000,55.430000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,186.920000,-38.240000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,242.190000,7.670000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,13.660000,-71.720000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,113.330000,-54.900000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,73.200000,71.290000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,145.270000,28.810000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,221.540000,-42.350000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,194.010000,-62.980000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314.680000,-61.460000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,115.550000,31.470000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,208.620000,-60.140000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,125.890000,-68.190000,0.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,119.360000,-19.380000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,81.030000,78.020000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,262.900000,79.350000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,196.970000,-19.210000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,135.240000,88.520000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,329.710000,-0.060000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,312.380000,-3.110000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,335.250000,-9.190000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,290.320000,-20.030000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,69.590000,38.660000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,285.060000,18.370000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,108.730000,41.050000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,152.600000,-15.770000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,308.670000,-61.720000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,108.940000,15.600000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,165.410000,51.780000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,10.080000,-81.140000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,72.020000,-60.900000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,73.290000,65.220000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,150.760000,18.540000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,196.430000,51.190000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,102.300000,62.920000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,120.370000,58.290000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,142.640000,-44.110000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,61.110000,9.530000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,127.780000,41.430000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,234.650000,7.440000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,273.720000,-85.770000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136.990000,-11.510000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,76.460000,18.120000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,344.130000,25.440000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,112.000000,-67.580000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,352.070000,17.800000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,236.340000,6.390000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,16.810000,30.190000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,305.480000,41.610000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,274.350000,18.720000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,175.420000,62.380000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,260.690000,25.470000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,62.160000,-65.890000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,191.830000,-59.190000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,181.700000,-10.270000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,283.770000,-86.170000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,30.040000,-35.890000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,32.510000,-29.240000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,183.180000,16.410000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,14.050000,-78.680000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,137.120000,60.540000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,84.390000,-86.830000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,107.860000,-76.490000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,99.530000,14.290000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,311.400000,-28.150000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,275.470000,83.370000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,243.740000,46.030000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,108.210000,-71.760000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,120.880000,-57.180000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,173.750000,-67.780000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,158.820000,5.710000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,328.090000,-11.430000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,213.560000,23.320000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,67.230000,-17.120000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,141.100000,35.790000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,327.170000,23.420000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,157.440000,-10.830000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,243.910000,59.630000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,118.580000,37.840000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,33.450000,-31.560000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,240.520000,54.890000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,271.790000,-71.310000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,19.260000,-29.450000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,94.930000,3.580000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,30.800000,38.540000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,78.870000,10.990000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,131.140000,-49.480000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,79.610000,41.940000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,176.280000,38.470000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,313.150000,6.960000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,22.220000,65.090000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,275.490000,10.520000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,244.960000,-77.820000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,182.630000,-66.610000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,340.500000,77.090000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,250.570000,23.060000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,164.840000,-32.920000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,335.310000,-27.850000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,293.980000,-78.290000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,292.850000,84.800000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,223.920000,-46.710000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,339.190000,31.060000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,170.660000,-84.770000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,330.330000,49.310000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,350.200000,-51.540000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,122.270000,-83.350000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,258.540000,-44.150000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,291.010000,7.280000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,111.680000,84.570000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,332.550000,-61.050000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,125.620000,56.510000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,102.890000,27.320000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,156.360000,46.690000,0.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,178.030000,-31.650000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,59.900000,49.650000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,53.970000,-31.250000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,52.240000,73.840000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,306.710000,4.320000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,349.380000,84.030000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,72.250000,86.420000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,87.320000,51.740000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,286.590000,-83.720000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,202.060000,-66.440000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,85.730000,87.500000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,189.600000,-62.360000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,45.670000,-23.640000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,265.940000,-1.970000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,22.410000,60.280000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,287.080000,77.110000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,231.950000,24.190000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,109.020000,35.980000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,170.290000,34.960000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,307.760000,-27.160000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,53.430000,-36.240000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,19.300000,-50.550000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,97.370000,-23.520000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,179.640000,5.440000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,158.110000,-27.860000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,284.780000,-79.200000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,91.650000,29.280000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,190.720000,-13.770000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,113.990000,60.350000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,113.460000,81.540000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,81.130000,-65.870000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,269.000000,-57.940000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,209.070000,66.110000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,153.340000,73.060000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,353.810000,-43.090000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,342.480000,72.100000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,11.350000,78.680000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,332.420000,-60.510000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,339.160000,56.640000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,168.830000,35.610000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,218.700000,12.490000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,20.770000,42.260000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,187.040000,57.890000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,249.510000,-68.400000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,100.180000,-31.980000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,351.050000,29.380000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,174.120000,-7.230000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,181.390000,-80.740000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,264.860000,-64.840000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316.530000,5.200000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,228.400000,-42.270000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,252.470000,-58.090000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,280.740000,56.930000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,205.210000,53.200000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,277.880000,5.540000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,30.750000,-21.590000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,75.820000,-56.940000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,305.090000,-53.220000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,250.560000,-5.910000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,164.230000,-0.090000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,298.100000,-5.220000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,184.170000,42.080000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,74.440000,47.190000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,220.910000,-1.290000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,155.580000,-78.320000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,130.450000,82.740000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,37.520000,7.360000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,128.790000,89.020000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,296.260000,30.430000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,71.930000,56.730000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,67.800000,40.650000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,175.870000,-40.240000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,288.140000,65.650000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,296.610000,45.130000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,93.280000,53.430000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,290.150000,19.380000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,59.220000,-77.330000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,12.490000,-37.030000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,41.960000,81.190000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,39.630000,-87.340000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,257.500000,72.320000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,227.570000,-88.050000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,201.840000,29.330000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,72.310000,-10.530000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,90.980000,77.790000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,149.850000,65.340000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,140.920000,25.990000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316.190000,-34.380000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,207.660000,63.350000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,67.330000,84.700000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,147.200000,-53.190000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,339.270000,-4.350000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,175.540000,-84.780000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,268.010000,48.710000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,148.680000,-88.240000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,69.550000,17.610000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,282.620000,-5.680000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,319.890000,13.990000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,73.360000,-46.070000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,155.030000,69.850000,0.8,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,96.900000,-58.890000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,150.970000,7.870000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,209.240000,-59.680000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,163.710000,-40.130000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,266.380000,72.340000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,49.250000,-86.810000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,124.320000,-75.330000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,23.590000,85.080000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,359.060000,-30.090000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,302.730000,-34.890000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,106.600000,32.220000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,22.670000,-14.400000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,302.940000,21.630000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,119.410000,59.940000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,84.080000,56.540000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,88.950000,29.080000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,26.020000,-25.970000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,147.290000,35.870000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,344.760000,28.310000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,150.430000,-72.510000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,176.300000,77.140000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314.370000,25.830000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,96.640000,-43.840000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,135.110000,25.920000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,321.780000,-38.660000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,188.650000,-17.720000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,347.720000,-0.610000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,330.990000,-36.630000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,30.460000,-73.870000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,58.130000,-6.020000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,306.000000,-7.130000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,306.070000,-74.420000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,310.340000,-39.110000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,210.810000,-45.190000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,259.480000,-56.240000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,348.350000,-10.210000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,9.420000,-82.220000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,214.690000,24.590000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136.160000,60.350000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,25.830000,81.580000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,135.700000,-63.580000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,357.770000,81.840000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224.040000,-47.160000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,346.510000,3.610000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,257.180000,40.790000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,208.050000,-31.380000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,91.120000,66.170000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,158.390000,76.520000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,301.860000,-12.020000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,53.530000,-12.710000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,25.400000,-55.220000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,109.470000,51.620000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,197.740000,89.000000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,182.210000,29.330000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314.880000,-10.570000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,127.750000,75.760000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,232.820000,-58.430000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,162.090000,36.160000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,167.560000,46.030000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,141.230000,-71.890000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,335.100000,-65.060000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,281.170000,-8.100000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,231.440000,46.370000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,77.910000,-51.040000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,72.580000,-53.310000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,107.450000,-11.790000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,74.520000,0.990000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,225.790000,60.510000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,93.260000,-88.510000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,288.930000,1.040000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,344.800000,63.920000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,152.870000,-60.300000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,325.140000,-78.050000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,33.610000,-80.500000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,250.280000,-50.450000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,147.150000,-17.030000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,336.220000,41.410000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,349.490000,6.570000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,78.960000,41.360000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136.630000,3.090000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,54.500000,8.720000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,84.570000,-7.990000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,118.840000,52.750000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,49.310000,-22.050000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,127.980000,-84.970000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,246.850000,37.040000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,297.920000,-80.150000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,173.190000,-28.650000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,124.660000,52.640000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44.330000,-28.750000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,184.200000,46.320000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,76.270000,-54.170000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,332.540000,-64.250000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,125.010000,41.310000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,65.680000,0.120000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,46.550000,7.430000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,319.620000,-86.700000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,56.890000,-68.160000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,230.360000,-17.670000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,12.030000,2.520000,1.6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,13.900000,-26.260000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,127.970000,18.160000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,246.240000,27.970000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,260.710000,86.580000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,63.380000,61.820000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,266.250000,-8.880000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,41.320000,-1.230000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,0.590000,-74.960000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,36.060000,-72.560000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,39.730000,73.900000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,263.600000,7.960000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,239.670000,-54.000000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,219.940000,-53.600000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,96.410000,-29.230000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,121.080000,17.130000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,185.950000,-34.870000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,183.020000,33.240000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,4.290000,47.950000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,261.760000,44.950000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,127.430000,42.390000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,213.300000,66.000000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,51.370000,66.360000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,253.640000,88.040000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,352.110000,-29.140000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,238.780000,23.050000,3.201,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,165.650000,-33.550000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,24.720000,-66.270000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,67.990000,-82.430000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,187.460000,11.880000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,275.130000,4.990000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,223.000000,-55.150000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,283.070000,56.220000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,347.340000,9.890000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,307.810000,63.870000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,56.480000,-63.410000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,205.350000,-87.920000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,286.420000,37.220000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,191.690000,-69.100000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,173.160000,-74.780000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,122.830000,-61.290000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,292.700000,41.510000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,214.770000,12.600000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,141.040000,48.960000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,323.510000,-73.210000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,294.180000,34.730000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,305.050000,-40.980000,3.201,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,248.120000,20.730000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,15.390000,4.950000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,218.860000,-58.030000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,30.530000,60.540000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,62.400000,-87.010000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,206.470000,-87.510000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,354.740000,62.230000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,39.210000,16.630000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,231.880000,-65.510000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,104.750000,-35.720000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,269.820000,-18.750000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,259.090000,-63.300000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,324.560000,-80.870000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,358.230000,-72.530000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,252.100000,76.270000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,258.170000,-27.110000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,268.440000,-33.280000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,174.910000,-49.630000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,229.580000,32.860000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,324.450000,24.840000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,351.520000,75.780000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,202.790000,-56.830000,3.201,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,130.260000,-46.290000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,25.930000,56.530000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,141.800000,28.370000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,9.870000,-69.190000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,242.140000,-80.580000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,10.610000,-54.970000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,287.280000,66.840000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,244.150000,-62.280000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,133.220000,-18.670000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,206.490000,-58.650000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,355.960000,22.690000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,113.630000,-55.310000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,91.500000,46.280000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,181.570000,-56.770000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,275.840000,-42.670000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,266.310000,-82.410000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44.980000,13.440000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,223.850000,-80.090000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,334.920000,-25.120000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,270.190000,88.240000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,281.660000,-16.910000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,261.330000,48.960000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,101.200000,-73.000000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,53.270000,47.170000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,9.540000,-2.540000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,222.010000,25.070000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,263.550000,68.410000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,236.620000,33.450000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,33.890000,60.850000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,267.360000,-68.100000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,109.030000,-13.650000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,170.900000,67.530000,3.2,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,344.970000,-20.390000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,163.240000,16.790000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,237.710000,-55.540000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,100.380000,32.460000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,3.250000,0.230000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,198.320000,14.030000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,217.590000,-43.840000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,313.060000,26.120000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,16.730000,-26.150000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,300.600000,24.870000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,336.670000,77.570000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,16.940000,52.340000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,313.410000,-47.240000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,38.080000,-1.110000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,162.950000,-67.650000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,220.020000,13.620000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,101.290000,-68.810000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,58.760000,-57.240000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,344.430000,-71.550000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,130.300000,-43.970000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,28.370000,18.050000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,290.640000,21.090000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,89.110000,26.980000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,35.780000,25.930000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,22.650000,-38.210000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,301.720000,9.220000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44.990000,22.930000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224.460000,-41.200000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,12.130000,7.180000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,20.000000,78.000000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,140.070000,78.030000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,264.340000,80.060000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,284.810000,24.100000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,93.480000,30.580000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,302.350000,65.530000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,83.420000,37.840000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,48.690000,-31.620000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,90.160000,51.260000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,99.830000,67.010000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,329.700000,-52.230000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,311.770000,54.520000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,298.040000,86.240000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,180.510000,41.140000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,211.180000,-10.160000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,282.050000,-79.410000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,285.120000,16.460000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,112.390000,-75.460000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,15.860000,77.130000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,247.530000,24.950000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,339.400000,82.360000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,183.470000,-15.470000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,31.740000,-43.360000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136.210000,55.090000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,28.880000,-59.280000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,321.750000,-16.040000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,186.820000,-77.900000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,236.090000,-71.590000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,1.560000,-46.590000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,95.230000,38.010000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,49.100000,-21.230000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,115.170000,-34.950000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,185.440000,28.240000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,151.910000,-77.050000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,266.580000,-19.800000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,61.450000,52.650000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,148.520000,-28.250000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,59.790000,77.000000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,47.260000,17.100000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,2.930000,-36.820000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,178.800000,-86.020000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,106.870000,-26.920000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,39.140000,-21.940000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,227.610000,-78.280000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,204.280000,85.300000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,221.150000,-16.360000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,170.220000,82.410000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,303.490000,-12.710000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,152.960000,-54.800000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,330.630000,77.450000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,8.500000,45.010000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,158.570000,45.620000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,312.840000,83.080000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,3.310000,28.410000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,201.980000,-66.990000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,80.850000,53.950000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,251.920000,51.080000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,247.190000,56.300000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,318.660000,14.710000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,358.330000,-2.160000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,258.200000,48.840000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,270.270000,-80.330000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,286.540000,-39.680000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,199.010000,-80.000000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,259.680000,-19.670000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,0.550000,60.570000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,33.620000,-85.230000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,250.890000,21.020000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,184.360000,22.640000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,86.030000,-58.650000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,207.900000,22.490000,6.4,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,46,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,46,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,134,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,134,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,226,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,226,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316,34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316,37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,44,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,46,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,46,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,134,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,134,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,136,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,224,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,226,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,226,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,314,-37,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316,-34,6,1,0);
select count(*) from test where q3c_ellipse_query(ra,dec,316,-37,6,1,0);
select count(*) from test where  q3c_ellipse_query(ra,dec,-45,-6,1,1,0);